==> systemc_3.0.0.orig.tar.xz: systemc-3.0.0/tests/systemc/utils/sc_report/test02/test02.cpp <==
/*****************************************************************************

  Licensed to Accellera Systems Initiative Inc. (Accellera) under one or
  more contributor license agreements.  See the NOTICE file distributed
  with this work for additional information regarding copyright ownership.
  Accellera licenses this file to you under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with the
  License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
  implied.  See the License for the specific language governing
  permissions and limitations under the License.

 *****************************************************************************/

/*****************************************************************************

  test02.cpp -- 

  Original Author: Martin Janssen, Synopsys, Inc., 2002-02-15

 *****************************************************************************/

/*****************************************************************************

  MODIFICATION LOG - modifiers, enter your name, affiliation, date and
  changes you are making here.

      Name, Affiliation, Date:
  Description of Modification:

 *****************************************************************************/

// test of reporting -- implementation

#include "systemc.h"

int
sc_main( int, char*[] )
{
    const int MY_ID = 9999;

    try {
        sc_report::register_id( -1, "first try" );
    }
    catch( sc_report x ) {
        cout << "\ncaught exception" << endl;
        cout << x.what() << endl;
    }

    try {
        sc_report::register_id( MY_ID, 0 );
    }
    catch( sc_report x ) {
        cout << "\ncaught exception" << endl;
        cout << x.what() << endl;
    }

    try {
        sc_report::register_id( MY_ID, "bogus message" );
        sc_report::register_id( MY_ID, "another bogus message" );
    }
    catch( sc_report x ) {
        cout << "\ncaught exception" << endl;
        cout << x.what() << endl;
    }

    cout << endl;
    cout << sc_report::get_message( 1234 ) << endl;

    sc_report::suppress_id( 4321, true );
    cout << endl;
    cout << sc_report::is_suppressed( 4321 ) << endl;

    return 0;
}

==> systemc_3.0.1.orig.tar.xz: systemc-3.0.1/tests/systemc/utils/sc_report/test02/test02.cpp <==
/*****************************************************************************

  Licensed to Accellera Systems Initiative Inc. (Accellera) under one or
  more contributor license agreements.  See the NOTICE file distributed
  with this work for additional information regarding copyright ownership.
  Accellera licenses this file to you under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with the
  License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
  implied.  See the License for the specific language governing
  permissions and limitations under the License.

 *****************************************************************************/

/*****************************************************************************

  test02.cpp -- 

  Original Author: Martin Janssen, Synopsys, Inc., 2002-02-15

 *****************************************************************************/

/*****************************************************************************

  MODIFICATION LOG - modifiers, enter your name, affiliation, date and
  changes you are making here.

      Name, Affiliation, Date:
  Description of Modification:

 *****************************************************************************/

// test of reporting -- implementation

#include "systemc.h"

int
sc_main( int, char*[] )
{
    const int MY_ID = 9999;

    try {
        sc_report::register_id( -1, "first try" );
    }
    catch( const sc_report & x ) {
        cout << "\ncaught exception" << endl;
        cout << x.what() << endl;
    }

    try {
        sc_report::register_id( MY_ID, 0 );
    }
    catch( const sc_report & x ) {
        cout << "\ncaught exception" << endl;
        cout << x.what() << endl;
    }

    try {
        sc_report::register_id( MY_ID, "bogus message" );
        sc_report::register_id( MY_ID, "another bogus message" );
    }
    catch( const sc_report & x ) {
        cout << "\ncaught exception" << endl;
        cout << x.what() << endl;
    }

    cout << endl;
    cout << sc_report::get_message( 1234 ) << endl;

    sc_report::suppress_id( 4321, true );
    cout << endl;
    cout << sc_report::is_suppressed( 4321 ) << endl;

    return 0;
}
